{ pkgs, lib, config, ... }:

let

in {
  # TASK: new device
  networking.hostName = "elias-e525"; # Define your hostname.

  networking.firewall.enable = true;
  networking.firewall.allowedTCPPorts = [
    # iperf3
    5201
  ];

  networking.firewall.logRefusedConnections = false;
  networking.usePredictableInterfaceNames = false;

  services.printing = {
    enable = true;
    drivers = with pkgs; [ mfcl3770cdw.driver mfcl3770cdw.cupswrapper ];
  };

  services.fprintd.enable = true;
  security.pam.services = {
    login.fprintAuth = true;
    sudo.fprintAuth = true;
  };

  services = {
    xserver = {
      layout = lib.mkForce "de";
      xkbVariant = lib.mkForce "";
      xkbOptions = lib.mkForce "";
      displayManager.autoLogin.enable = lib.mkForce false;
      displayManager.gdm.enable = lib.mkForce true;
      displayManager.lightdm.enable = lib.mkForce false;
      desktopManager.gnome.enable = true;
    };

    # dbus.packages = [ pkgs.gnome3.dconf ];
    # udev.packages = [ pkgs.gnome3.gnome-settings-daemon ];
  };

  security.pki.certificateFiles =
    [ "${pkgs.cacert}/etc/ssl/certs/ca-bundle.crt" ];

  services.xserver.videoDrivers = [ "modesetting" ];

  boot.kernelPackages = lib.mkForce pkgs.linuxPackages_latest;
}
